@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: mozilla-link-checker.cpp,v 1.9 2004/04/19 04:00:43 adamh Exp $
+ *  $Id: mozilla-link-checker.cpp,v 1.10 2004/09/07 13:02:49 chpe Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -132,7 +132,9 @@ mozilla_check_links (LinkChecker *checker,
 
 	nsCOMPtr<ErrorViewerURICheckerObserver> observer = do_CreateInstance
 		(G_ERRORVIEWERURICHECKEROBSERVER_CONTRACTID);
-	observer->Init (checker, ephy_embed_get_location (embed, FALSE));
+	char *url = ephy_embed_get_location (embed, FALSE);
+	observer->Init (checker, url);
+	g_free (url);
 
 	PRUint32 numLinks;
 	rv = links->GetLength (&numLinks);
