@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-gestures-extension.c,v 1.10.2.1 2004/09/26 16:22:39 chpe Exp $
+ *  $Id: ephy-gestures-extension.c,v 1.14 2004/09/26 16:07:58 chpe Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -286,7 +286,7 @@ gesture_performed_cb (EphyGesture *gesture,
 		GtkUIManager *manager;
 		GtkAction *action;
 		
-		manager = GTK_UI_MANAGER (window->ui_merge);
+		manager = GTK_UI_MANAGER (ephy_window_get_ui_manager (window));
 		
 		action = gtk_ui_manager_get_action (manager, path);
 		
@@ -372,24 +372,24 @@ tab_removed_cb (GtkWidget *notebook,
 }
 
 static void
-impl_attach_window (EphyExtension *extension,
+impl_attach_window (EphyExtension *ext,
 		    EphyWindow *window)
 {
+	EphyGesturesExtension *extension = EPHY_GESTURES_EXTENSION (ext);
 	GtkWidget *notebook;
 	GList *tabs, *l;
 
+	notebook = ephy_window_get_notebook (window);
+
 	tabs = ephy_window_get_tabs (window);
 
-	for (l = tabs; l != NULL; l = g_list_next (l))
+	for (l = tabs; l != NULL; l = l->next)
 	{
-		tab_added_cb (NULL, l->data,
-			      (EphyGesturesExtension *) extension);
+		tab_added_cb (notebook, (EphyTab *) l->data, extension);
 	}
 
 	g_list_free (tabs);
 
-	notebook = ephy_window_get_notebook (window);
-
 	g_signal_connect (notebook, "tab_added",
 			  G_CALLBACK (tab_added_cb), extension);
 	g_signal_connect (notebook, "tab_removed",
@@ -397,9 +397,10 @@ impl_attach_window (EphyExtension *extension,
 }
 
 static void
-impl_detach_window (EphyExtension *extension,
+impl_detach_window (EphyExtension *ext,
 		    EphyWindow *window)
 {
+	EphyGesturesExtension *extension = EPHY_GESTURES_EXTENSION (ext);
 	GtkWidget *notebook;
 	GList *tabs, *l;
 
@@ -414,8 +415,7 @@ impl_detach_window (EphyExtension *extension,
 
 	for (l = tabs; l != NULL; l = g_list_next (l))
 	{
-		tab_removed_cb (NULL, l->data,
-				(EphyGesturesExtension *) extension);
+		tab_removed_cb (notebook, (EphyTab *) l->data, extension);
 	}
 
 	g_list_free (tabs);
