@@ -22,7 +22,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: page-info-dialog.c,v 1.20.2.3 2004/10/08 16:58:32 chpe Exp $
+ *  $Id: page-info-dialog.c,v 1.27 2004/10/08 16:57:58 chpe Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -34,9 +34,10 @@
 
 #include <epiphany/ephy-embed-persist.h>
 #include <epiphany/ephy-embed-factory.h>
+#include <epiphany/ephy-state.h>
 
 /* non-installed ephy headers */
-#include "ephy-state.h"
+#include "ephy-gui.h"
 #include "eel-gconf-extensions.h"
 #include "ephy-file-helpers.h"
 
@@ -503,7 +504,8 @@ treeview_info_page_show_popup (TreeviewInfoPage *page)
 
 	widget = gtk_ui_manager_get_widget (dialog->priv->manager,
 					    page->popup_path);
-	gtk_menu_popup (GTK_MENU (widget), NULL, NULL, NULL, NULL, 2,
+	gtk_menu_popup (GTK_MENU (widget), NULL, NULL,
+			ephy_gui_menu_position_tree_selection, page->treeview, 2,
 			gtk_get_current_event_time ());
 
 	return TRUE;
@@ -514,10 +516,13 @@ treeview_info_page_button_pressed_cb (GtkTreeView *treeview,
 				      GdkEventButton *event,
 				      TreeviewInfoPage *page)
 {
+	InfoPage *ipage = (InfoPage *) page;
+	PageInfoDialog *dialog = ipage->dialog;
 	GtkTreeModel *model = GTK_TREE_MODEL (page->store);
 	GtkTreeSelection *selection;
 	GtkTreeIter iter;
 	GtkTreePath *path = NULL;
+	GtkWidget *widget;
 
 	/* right-click? */
 	if (event->button != 3)
@@ -545,7 +550,13 @@ treeview_info_page_button_pressed_cb (GtkTreeView *treeview,
 	gtk_tree_selection_select_path (selection, path);
 	gtk_tree_path_free (path);
 
-	return treeview_info_page_show_popup (page);
+	/* now popup the menu */
+	widget = gtk_ui_manager_get_widget (dialog->priv->manager,
+					    page->popup_path);
+	gtk_menu_popup (GTK_MENU (widget), NULL, NULL, NULL, NULL, 2,
+			gtk_get_current_event_time ());
+
+	return TRUE;
 }
 
 static void
@@ -796,7 +807,7 @@ images_save_image_cb (gpointer ptr,
 	if (address == NULL) return;
 
 	persist = EPHY_EMBED_PERSIST
-		(ephy_embed_factory_new_object ("EphyEmbedPersist"));
+		(ephy_embed_factory_new_object (EPHY_TYPE_EMBED_PERSIST));
 
 	ephy_embed_persist_set_source (persist, address);
 	ephy_embed_persist_set_flags (persist, EMBED_PERSIST_ASK_DESTINATION);
@@ -842,7 +853,7 @@ images_set_image_as_background_cb (GtkAction *action,
 	dest = g_build_filename (ephy_dot_dir (), base_converted, NULL);
 
 	persist = EPHY_EMBED_PERSIST
-		(ephy_embed_factory_new_object ("EphyEmbedPersist"));
+		(ephy_embed_factory_new_object (EPHY_TYPE_EMBED_PERSIST));
 
 	ephy_embed_persist_set_source (persist, address);
 	ephy_embed_persist_set_dest (persist, dest);
@@ -914,7 +925,7 @@ page_info_image_box_realize_cb (GtkContainer *box,
 	ImagesInfoPage *page = (ImagesInfoPage *) tpage;
 	EphyEmbed *embed;
 
-	page->embed = embed = EPHY_EMBED (ephy_embed_factory_new_object ("EphyEmbed"));
+	page->embed = embed = EPHY_EMBED (ephy_embed_factory_new_object (EPHY_TYPE_EMBED));
 
 	/* FIXME: this doesn't seem to work!? */
 	/* When the image has loaded grab the focus for the treeview
@@ -1478,6 +1489,9 @@ page_info_dialog_constructor (GType type,
 
 	dialog->priv->dialog = ephy_dialog_get_control (edialog, properties[PROP_DIALOG].id);
 
+	gtk_window_set_icon_name (GTK_WINDOW (dialog->priv->dialog),
+				  GTK_STOCK_PROPERTIES);
+
 	dialog->priv->manager = gtk_ui_manager_new ();
 	dialog->priv->action_group = gtk_action_group_new ("PageInfoContextActions");
 	gtk_action_group_set_translation_domain (dialog->priv->action_group,
