@@ -16,19 +16,25 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: sample-mozilla.c,v 1.2 2004/08/26 19:51:44 chpe Exp $
+ *  $Id: sample-mozilla.c,v 1.5 2004/11/01 14:24:35 chpe Exp $
  */
 
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
 #include "ephy-sample2-extension.h"
 #include "ephy-debug.h"
 
 #include <gmodule.h>
 #include <glib/gi18n-lib.h>
 
+G_MODULE_EXPORT GType register_module (GTypeModule *module);
+
 G_MODULE_EXPORT GType
 register_module (GTypeModule *module)
 {
-	LOG ("Registering EphySampleExtension")
+	LOG ("Registering EphySample2Extension")
 
 #ifdef ENABLE_NLS
        /* Initialise the i18n stuff */
